kernaux
=======

[![Test](https://github.com/tailix/libkernaux/actions/workflows/test.yml/badge.svg)](https://github.com/tailix/libkernaux/actions/workflows/test.yml)

Bindings to **libkernaux** - auxiliary library for kernel development.
